@@ -89,6 +89,9 @@ static const PkEnumMatch enum_status_icon_name[] = {
 	{PK_STATUS_ENUM_TEST_COMMIT,		"pk-package-info"}, /* TODO: need better icon */
 	{PK_STATUS_ENUM_UPDATE,			"pk-package-update"},
 	{PK_STATUS_ENUM_WAIT,			"pk-wait"},
+	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
 	{0, NULL}
 };
 
@@ -126,6 +129,9 @@ static const PkEnumMatch enum_status_animation[] = {
 	{PK_STATUS_ENUM_TEST_COMMIT,		"pk-action-testing"},
 	{PK_STATUS_ENUM_UPDATE,			"pk-action-installing"},
 	{PK_STATUS_ENUM_WAIT,			"pk-action-waiting"},
+	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
 	{0, NULL}
 };
 
@@ -209,6 +215,8 @@ static const PkEnumMatch enum_restart_icon_name[] = {
 	{PK_RESTART_ENUM_SYSTEM,		"system-shutdown"},
 	{PK_RESTART_ENUM_SESSION,		"system-log-out"},
 	{PK_RESTART_ENUM_APPLICATION,		"emblem-symbolic-link"},
+	{PK_RESTART_ENUM_SECURITY_SYSTEM,	"system-shutdown"},
+	{PK_RESTART_ENUM_SECURITY_SESSION,	"system-log-out"},
 	{0, NULL}
 };
 
@@ -218,6 +226,8 @@ static const PkEnumMatch enum_restart_dialog_icon_name[] = {
 	{PK_RESTART_ENUM_SYSTEM,		"dialog-error"},
 	{PK_RESTART_ENUM_SESSION,		"dialog-warning"},
 	{PK_RESTART_ENUM_APPLICATION,		"dialog-warning"},
+	{PK_RESTART_ENUM_SECURITY_SYSTEM,	"dialog-error"},
+	{PK_RESTART_ENUM_SECURITY_SESSION,	"dialog-error"},
 	{0, NULL}
 };
 
@@ -235,6 +245,7 @@ static const PkEnumMatch enum_message_icon_name[] = {
 	{PK_MESSAGE_ENUM_COULD_NOT_FIND_PACKAGE,"dialog-error"},
 	{PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED,	"dialog-information"},
+	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED,	"dialog-information"},
 	{0, NULL}
 };
 
@@ -490,7 +501,7 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 	switch (code) {
 	case PK_ERROR_ENUM_NO_NETWORK:
 		text = _("There is no network connection available.\n"
-			 "Please check your connection settings and try again");
+			 "Please check your connection settings and try again.");
 		break;
 	case PK_ERROR_ENUM_NO_CACHE:
 		text = _("The package list needs to be rebuilt.\n"
@@ -554,7 +565,7 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_FOUND:
 		text = _("The remote software source name was not found.\n"
-			 "You may need to enable an item in Software Sources");
+			 "You may need to enable an item in Software Sources.");
 		break;
 	case PK_ERROR_ENUM_CANNOT_REMOVE_SYSTEM_PACKAGE:
 		text = _("Removing a protected system package is not allowed.");
@@ -590,7 +601,7 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 			 "This is usually due to mixing packages from different software sources.");
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_AVAILABLE:
-		text = _("There was a (possibly temporary) problem connecting to a software source\n"
+		text = _("There was a (possibly temporary) problem connecting to a software source.\n"
 			 "Please check the detailed error for further details.");
 		break;
 	case PK_ERROR_ENUM_FAILED_INITIALIZATION:
@@ -661,7 +672,8 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 		text = _("Additional media is required to complete the transaction.");
 		break;
 	case PK_ERROR_ENUM_NOT_AUTHORIZED:
-		text = _("You have failed to provide correct authentication. Please check any passwords or account settings.");
+		text = _("You have failed to provide correct authentication.\n"
+			 "Please check any passwords or account settings.");
 		break;
 	case PK_ERROR_ENUM_UPDATE_NOT_FOUND:
 		text = _("The specified update could not be found.\n"
@@ -698,16 +710,22 @@ gpk_restart_enum_to_localised_text_future (PkRestartEnum restart)
 	const gchar *text = NULL;
 	switch (restart) {
 	case PK_RESTART_ENUM_NONE:
-		text = _("No restart is necessary");
+		text = _("No restart is necessary.");
 		break;
 	case PK_RESTART_ENUM_APPLICATION:
-		text = _("You will be required to restart this application");
+		text = _("You will be required to restart this application.");
 		break;
 	case PK_RESTART_ENUM_SESSION:
-		text = _("You will be required to log out and back in");
+		text = _("You will be required to log out and back in.");
 		break;
 	case PK_RESTART_ENUM_SYSTEM:
-		text = _("A restart will be required");
+		text = _("A restart will be required.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SESSION:
+		text = _("You will be required to log out and back in due to a security update.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SYSTEM:
+		text = _("A restart will be required due to a security update.");
 		break;
 	default:
 		egg_warning ("restart unrecognised: %i", restart);
@@ -724,16 +742,22 @@ gpk_restart_enum_to_localised_text (PkRestartEnum restart)
 	const gchar *text = NULL;
 	switch (restart) {
 	case PK_RESTART_ENUM_NONE:
-		text = _("No restart is required");
+		text = _("No restart is required.");
 		break;
 	case PK_RESTART_ENUM_SYSTEM:
-		text = _("A restart is required");
+		text = _("A restart is required.");
 		break;
 	case PK_RESTART_ENUM_SESSION:
-		text = _("You need to log out and log back in");
+		text = _("You need to log out and log back in.");
 		break;
 	case PK_RESTART_ENUM_APPLICATION:
-		text = _("You need to restart the application");
+		text = _("You need to restart the application.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SESSION:
+		text = _("You need to log out and log back in to remain secure.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SYSTEM:
+		text = _("A restart is required to remain secure.");
 		break;
 	default:
 		egg_warning ("restart unrecognised: %i", restart);
@@ -811,7 +835,9 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 	case PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED:
 		text = _("Package is already installed");
 		break;
-
+	case PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED:
+		text = _("Automatic cleanup is being ignored");
+		break;
 	default:
 		egg_warning ("message unrecognised: %i", message);
 	}
@@ -955,9 +981,21 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		text = _("Waiting for package manager lock");
 		break;
 	case PK_STATUS_ENUM_WAITING_FOR_AUTH:
-		/* TRANSLATORS: waitig for user to type in a password */
+		/* TRANSLATORS: waiting for user to type in a password */
 		text = _("Waiting for authentication");
 		break;
+	case PK_STATUS_ENUM_SCAN_PROCESS_LIST:
+		/* TRANSLATORS: we are updating the list of processes */
+		text = _("Updating the list of running applications");
+		break;
+	case PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES:
+		/* TRANSLATORS: we are checking executable files in use */
+		text = _("Checking for applications currently in use");
+		break;
+	case PK_STATUS_ENUM_CHECK_LIBRARIES:
+		/* TRANSLATORS: we are checking for libraries in use */
+		text = _("Checking for libraries currently in use");
+		break;
 	default:
 		egg_warning ("status unrecognised: %s", pk_status_enum_to_text (status));
 	}
@@ -1714,7 +1752,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the role icon name enums");
 	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
 		string = gpk_role_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_role_enum_to_text (i));
 			break;
 		}
@@ -1725,7 +1763,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the status animation enums");
 	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
 		string = gpk_status_enum_to_animation (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_role_enum_to_text (i));
 			break;
 		}
@@ -1736,7 +1774,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the info icon names enums");
 	for (i=0; i<PK_INFO_ENUM_UNKNOWN; i++) {
 		string = gpk_info_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_info_enum_to_text (i));
 			break;
 		}
@@ -1758,7 +1796,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the status icon names enums");
 	for (i=0; i<PK_STATUS_ENUM_UNKNOWN; i++) {
 		string = gpk_status_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_status_enum_to_text (i));
 			break;
 		}
@@ -1769,7 +1807,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the restart icon names enums");
 	for (i=0; i<PK_RESTART_ENUM_UNKNOWN; i++) {
 		string = gpk_restart_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_restart_enum_to_text (i));
 			break;
 		}
@@ -1813,7 +1851,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the message icon name enums");
 	for (i=0; i<PK_MESSAGE_ENUM_UNKNOWN; i++) {
 		string = gpk_message_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_message_enum_to_text (i));
 			break;
 		}
@@ -1857,7 +1895,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the group icon name enums");
 	for (i=0; i<PK_GROUP_ENUM_UNKNOWN; i++) {
 		string = gpk_group_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_group_enum_to_text (i));
 			break;
 		}
